<?php
/**
 * Initialize Plugin
 *
 * Enqueue CSS/JS for Gutenberg on SANGO default styles and  all the blocks.
 *
 * @since   1.0.0
 * @package SGB
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Enqueue Gutenberg block assets for both frontend + Gutenberg.
 *
 * @since 1.0.0
 */

function sango_theme_gutenberg_common_assets() { // phpcs:ignore
	// Styles.
	wp_enqueue_style(
		'sango_theme_gutenberg-style',
		plugins_url( 'dist/blocks.style.build.css?ver', dirname( __FILE__ ) ).SGB_VER_NUM
	);
}

// Hook: Frontend assets.
add_action( 'enqueue_block_assets', 'sango_theme_gutenberg_common_assets' );

/**
 * Enqueue Gutenberg block assets for Gutenberg editor.
 *
 * @since 1.0.0
 */
function sango_theme_gutenberg_editor_assets() { // phpcs:ignore
    
	// Scripts.
	wp_enqueue_script(
		'sango_theme_gutenberg-block-js', // Handle.
		plugins_url( '/dist/blocks.build.js?ver', dirname( __FILE__ ) ).SGB_VER_NUM,
    array( 'wp-blocks', 'wp-element', 'wp-editor', 'wp-rich-text' )
  );
  
  // 親テーマのget_optionの値を全てエディターのJSにわたす->必要に応じてブロックで利用
  // $editor_include_options = wp_load_alloptions();
  $editor_include_options = array(
    'say_image_upload' => get_option("say_image_upload"),
    'say_name' => get_option("say_name"),
  );
  wp_localize_script( 'sango_theme_gutenberg-block-js', 'sgb_parent_options', $editor_include_options );

	// Block Editor Styles.
	wp_enqueue_style(
		'sango_theme_gutenberg-block-editor-style', // Handle.
		plugins_url( 'dist/blocks.editor.build.css?ver', dirname( __FILE__ ) ).SGB_VER_NUM,
    array( 'wp-edit-blocks' )
  );
  // Custom styles from SANGO theme.
  wp_add_inline_style( 'sango_theme_gutenberg-block-editor-style', sango_theme_parent_colors().sgb_custom_colors() );
}

// Hook: Editor assets.
add_action( 'enqueue_block_editor_assets', 'sango_theme_gutenberg_editor_assets' );

/**
 * Include FontAwesome to Gutenberg editor
 *
 * @since 1.0.0
 */
function sango_theme_gutenberg_font_awesome() { // phpcs:ignore
  $fontawesome5_ver = get_option('fontawesome5_ver_num') ? preg_replace("/( |　)/", "", get_option('fontawesome5_ver_num') ) : '5.7.2';
  wp_enqueue_style(
    'sango_theme_gutenberg_font_awesome',
    'https://use.fontawesome.com/releases/v'. $fontawesome5_ver .'/css/all.css'
  );
}
add_action( 'enqueue_block_editor_assets', 'sango_theme_gutenberg_font_awesome' );

/**
 * Register SANGO custom block category
 *
 * @since 1.0.0
 */
function sango_theme_gutenberg_register_block_category( $categories ) {
  $categories[] = [
    'slug'  => 'sgb_custom',
    'title' => 'SANGOカスタムブロック'
  ];
  return $categories;
}
add_filter( 'block_categories', 'sango_theme_gutenberg_register_block_category' );

/**
 * Register SANGO custom inline css (Frontend + Backend)
 *
 * @since 1.0.4
 */
function sango_theme_gutenberg_custom_inline_css() { // phpcs:ignore
  wp_add_inline_style( 'sango_theme_gutenberg-style', sgb_custom_colors() );
}
add_action( 'wp_enqueue_scripts', 'sango_theme_gutenberg_custom_inline_css' );